#
# spec file for package pluma
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define typelib typelib-1_0-Pluma-1_0
%define _version 1.20
Name:           pluma
Version:        1.20.0
Release:        lp150.1.2
Summary:        Text editor for the MATE desktop
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE pluma-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch0:         pluma-gtk-3.20.patch
BuildRequires:  fdupes
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(sm)
Requires:       mate-desktop-gsettings-schemas
Recommends:     %{name}-lang
# mate-text-editor was last used in openSUSE 13.1.
Provides:       mate-text-editor = %{version}
Obsoletes:      mate-text-editor < %{version}
Obsoletes:      mate-text-editor-lang < %{version}
%glib2_gsettings_schema_requires

%description
Pluma is a small, but powerful text editor designed specifically
for the MATE desktop. It has most standard text editor functions
and fully supports international text in Unicode. Advanced features
include syntax highlighting and automatic indentation of source
code, printing and editing of multiple documents in one window.

Pluma is extensible through a plugin system, which currently
includes support for spell checking, comparing files, viewing VCS
ChangeLogs, and adjusting indentation levels.

%package devel
Summary:        Small and lightweight UTF-8 text editor
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{typelib} = %{version}
Requires:       pkgconfig(gtksourceview-3.0)
# mate-text-editor-devel was last used in openSUSE 13.1.
Provides:       mate-text-editor-devel = %{version}
Obsoletes:      mate-text-editor-devel < %{version}

%description devel
pluma is a small, but powerful text editor designed specifically
for the MATE desktop. It has most standard text editor functions
and fully supports international text in Unicode. Advanced features
include syntax highlighting and automatic indentation of source
code, printing and editing of multiple documents in one window.

%package -n %{typelib}
Summary:        Small and lightweight UTF-8 text editor introspection
Group:          System/Libraries

%description -n %{typelib}
pluma is a small, but powerful text editor designed specifically
for the MATE desktop. It has most standard text editor functions
and fully supports international text in Unicode. Advanced features
include syntax highlighting and automatic indentation of source
code, printing and editing of multiple documents in one window.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%post
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_post
%glib2_gsettings_schema_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_postun
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_libdir}/%{name}/
%{_libexecdir}/%{name}/
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/help/C/%{name}/

%files devel
%doc %{_datadir}/gtk-doc/html/
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/gir-1.0/Pluma-1.0.gir

%files -n %{typelib}
%{_libdir}/girepository-1.0/Pluma-1.0.typelib

%files lang -f %{name}.lang

%changelog
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Double click to the right of the last open tab to open a new
    tab.
  * Support new location of the Gtk bookmarks file.
  * docs: We have encodings combobox, not option menu.
  * Remove references to PlumaStatus.
  * docs: Remove some references to nonexistent stuff.
  * filebrowser: Don't parse .hidden files - GIO does it since
    2.36.
  * Don't request to save documents with no changes.
  * Add a gsettings key to hide/show(default) tabs with the side
    pane.
  * Hide tabs if the sidebar is used.
  * Enable the ability to save the document if it was changed
    externally.
  * Disable the ability to save the document if it has no changes.
  * pluma-window: Have GtkRecentData on stack instead of allocating
    it.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Fix regexp replacement with backreferences (e.g. "\0").
  * Make sure pluma opens in the same window of the workspace.
  * Add a gsettings key: Show save confirmation if the files have
    changes.
  * Put "peas_engine_enable_loader" in the correct pl.
  * Make the list of recently used files work again.
  * Fix some deprecations.
  * Silent some build warnings.
  * Update translations.
- Add pluma-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20 support.
* Tue Nov 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.3:
  * Fix pluma closing tabs unexpectedly with the [right+middle]
    click.
  * Fix wrong behaviour when holding down a [middle + right] click.
  * Fix pluma closing tabs unexpectedly with a middle click.
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Improve the close-confirm dialogue.
  * Update translations.
* Tue Apr  4 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix running under Wayland.
  * modelines: Fix random crash on closing one of several Pluma
    windows.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Build: Actually build GObject introspection data.
  * Build: Remove the --enable-deprecations option - it actually
    disables all deprecated stuff.
  * Add the ability to search/replace text using regular expressions.
  * Drop Python bindings and the --enable-python build option.
  * Port the plugin system and both C and Python plugins to libpeas.
  * Snippets plugin: Stop exposing functions on Pluma message bus
    (doesn't work with GObject introspection).
  * Snippets plugin: Fix snippet parts staying after Ctrl-Z.
  * Fix an unexpected closing of the first tab with middle-click
    under the line numbers column.
  * Fix some runtime warnings in plugins.
  * Some more fixes and cleanups in code and docs.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Drop dependency on libmate-desktop and --without-matedesktop
    build option.
  * GTK+3: Fix lots of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Enable spell checking for new documents when Always Autocheck
    option is selected in Spell Check plugin.
  * Fix restoring cursor position when loading a document.
  * Install externaltools plugin only with Python support enabled.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Fix Changelog generation.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Make switch-c tool in external tools work, fix security a issue.
  * GTK+3: Add style class pluma-window and pluma-print-preview.
* Fri Feb 19 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * GTK+3: Fix several deprecations.
  * Implement middle-click tab closing.
  * Drop MateConf migration script.
  * Add a new Configure dialog for the Spell Check plugin.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 1.12.2:
  * Python console plugin: Fix missing icon in plugin list.
  * Fix possible use-after-free during incremental search.
  * GTK+3: Fix incremental search entry colour when text isn't
    found.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Add --without-matedesktop option to enable build without
    dependency on libmate-desktop.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Add --enable-tests option to enable/disable running tests
    during the build.
  * Add plugin to strip trailing spaces on saving.
  * Bring back active plugins listing in bugreport script.
  * Drop support for win32/osx and checkupdate plugin.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Capitalise Pluma in window titles and desktop file.
  * Some annotation fixes.
  * Some minor fixes and cleanups.
* Wed Jul 15 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Window title: display full path to files on mounted drives.
  * Close confirmation dialog: make text unfocusable.
  * Quickopen plugin: fix filebrowser plugin support.
  * Time plugin: GTK+3 fix.
  * Multiple help fixes.
* Fri Jun 19 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix gschema translations.
  * Gtk3 fixes.
  * Fix man page formatting.
  * Build system fixes.
* Thu May  7 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.1):
  * Fix GLib >= 2.43 compatibility.
  * Update translations.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  * Bug fixes release
* Fri Nov 28 2014 p.drouand@gmail.com
- Fix boo#906911,add mate-desktop-gsettings-schemas as a
  dependency
* Tue Nov 25 2014 hillwood@opensuse.org
- Fix boo#906911,add mate-desktop-gsettings-schemas as a
  dependency
* Sun Nov 23 2014 p.drouand@gmail.com
- Add pkgconfig(mate-desktop-2.0) build dependency; new build
  requirement
* Mon Jul 14 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Use MateAboutDialog from libmate-desktop
- Move from GTK2 to GTK3
  + Replace pkgconfig(gtk+-2.0) with pkgconfig(gtk+-3.0) requirement
  + Remove pkgconfig(pygtk-2.0) and pkgconfig(pygtksourceview-2.0)
    build require
  + Replace pkgconfig(pygobject-2.0) with pkgconfig(pygobject-3.0)
    requirement
  + Pass "with-gtk=3.0" in configure
* Thu May  1 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + fix go to line crash
  + translations updates
* Wed Mar 12 2014 p.drouand@gmail.com
- Obsolete mate-text-editor-lang to avoid conflicts with this one
* Mon Mar 10 2014 p.drouand@gmail.com
- Obsolete mate-text-editor-devel with pluma-devel; add a Obsoletes
  tag
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + add GTK3 support
  + use yelp-tools instead of mate-doc-utils
  + move user plugin dir from config_dir to data_dir. Plugins should have
    never been installed in the config dir as they are not part of the
    configuration. This means user will need to move the plugins directory
    from: $HOME/.config/pluma/ to $HOME/.local/share/pluma/.
* Fri Feb 14 2014 p.drouand@gmail.com
- Update to version 1.7.2 (unstable)
  + update translation
  + bugs fixed
  + add tool to generate plugin templates
* Sun Jan 19 2014 p.drouand@gmail.com
- Update to version 1.7.1 (unstable)
  + update translations
  + fix Sun GNOME Documentation Team references
  + fix search fields in GTK3
  + fix make dist
  + add the primary-toolbar style class to the primary toolbar
  + add section for running tests
  + update bug tracker url
  + gtk3: fix implicit declaration: gtk_source_language_get_id
  + use Caja GSettings schema optionally
    This makes Caja dependency optional.
  + bump required glib version number to 2.32
    It's required for the GSettingsSchemaSource API.
  + Add  to ACLOCAL_AMFLAGS for user added flags
  + plumadirs: Cleanup config dir usage
    Remove backwards compatibility for < glib 2.6 as we require glib
    2.22 at
    a minimum now.
    Use g_get_user_config_dir instead of custom logic.
    Use pluma_dirs_get_user_config_dir in pluma_dirs_get_user_accels_file.
  + pluma-dirs: Fix accel file location
  + move user plugins dir to data_dir
    Plugins don't belong in config_dir so we move them to data_dir.
    User will need to move the plugin dir to the new location, see NEWS.
  + update translations
* Fri Jan 17 2014 p.drouand@gmail.com
- Initial release (version 1.7.0)
